// Copyright (c) 2008, David Smith
// All rights reserved.
//
// Redistribution and use in source and binary forms, with or without
// modification, are permitted provided that the following conditions are met:
//     * Redistributions of source code must retain the above copyright
//       notice, this list of conditions and the following disclaimer.
//     * Redistributions in binary form must reproduce the above copyright
//       notice, this list of conditions and the following disclaimer in the
//       documentation and/or other materials provided with the distribution.
//     * Neither the name of PaperPlane nor the
//       names of its contributors may be used to endorse or promote products
//       derived from this software without specific prior written permission.
//
// THIS SOFTWARE IS PROVIDED BY DAVID SMITH ``AS IS'' AND ANY
// EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
// WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
// DISCLAIMED. IN NO EVENT SHALL DAVID SMITH BE LIABLE FOR ANY
// DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
// (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
// LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
// ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
// (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
// SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

import ucigame.*;

public class PaperPlane extends Ucigame
{
    int x, y, x1, y1;
    int planeRadius = 30;
    Sprite plane;
    Sprite vent;
    Sprite shelf;
    Sprite desk;
    Sprite floor;
    Sprite button1;
    Sprite button2;
    Sprite button3;
    Sprite bBall;
    Sprite rBall;
    Sprite gBall;
    int level;

    public void setup()
    {
        window.size(1250, 800);
        window.title("Paper Airplane");
        window.showFPS();
        canvas.background(219, 112, 147);

		bBall = makeSprite(getImage("images/BlueBall.GIF", 255, 255, 255));
		rBall = makeSprite(getImage("images/RedBall.GIF", 255, 255, 255));
		gBall = makeSprite(getImage("images/GreenBall.GIF", 255, 255, 255));
        plane = makeSprite(getImage("images/Plane.GIF", 255, 255, 255));
        vent = makeSprite(getImage("images/Vent.GIF", 255, 255, 255));
        shelf = makeSprite(getImage("images/Shelf.GIF", 255, 255, 255));
        desk = makeSprite(getImage("images/Desk.GIF", 255, 255, 255));
        floor = makeSprite(getImage("images/Floor.GIF", 255, 255, 255));
        button1 = makeButton("Play",
		                      getImage("images/Play.GIF", 255, 255, 255),
                             150, 48);
        button2 = makeButton("PlayAgain",
				              getImage("images/Again.GIF", 255, 255, 255),
                             150, 48);
        button3 = makeButton("NextLevel",
							 getImage("images/Level.GIF", 255, 255, 255),
                             150, 48);
        x = canvas.width()-1200;
        y = canvas.height()-750;
        x1 = canvas.width()/2 - 50;
        y1 = canvas.height()/2 - 50;
        plane.position(x, y);
        vent.position(x, canvas.height()-50);
        shelf.position(canvas.width()/2, canvas.height() - 600);
        desk.position(x1 + 200, canvas.height()-100);
        floor.position(canvas.width()-1250, canvas.height()-100);
        button2.position(x1, y1);
        button1.position(x1, y1);
        button3.position(x1, y1);
		bBall.position(canvas.width()/2, canvas.height()/2);
		rBall.position(canvas.width() - 50, canvas.height() - 50);
		gBall.position(canvas.width()/2, canvas.height() - 50);
		bBall.motion(3, 2);
		rBall.motion(1, 3);
		gBall.motion(2, 3);

        level = 0;

        framerate(30);
    }

    public void draw()
    {
        canvas.clear();

        if(level == 0)
        {
			button1.draw();
		}

		if(level == 1)
		{
		bBall.move();
		rBall.move();
		gBall.move();
		bBall.bounceIfCollidesWith(TOPEDGE, BOTTOMEDGE, LEFTEDGE, RIGHTEDGE, shelf, desk, rBall, gBall);
		rBall.bounceIfCollidesWith(TOPEDGE, BOTTOMEDGE, LEFTEDGE, RIGHTEDGE, shelf, desk, bBall, gBall);
		gBall.bounceIfCollidesWith(TOPEDGE, BOTTOMEDGE, LEFTEDGE, RIGHTEDGE, shelf, desk, rBall, bBall);
        if (keyboard.isDown(keyboard.LEFT, keyboard.A))
		    plane.nextX(plane.x() - 5);
		if (keyboard.isDown(keyboard.RIGHT, keyboard.D))
            plane.nextX(plane.x() + 5);
		if (plane.x() > x -50 && plane.x() < x + vent.width() - 50)
		{
			if(plane.y() > 50)
				plane.nextY(plane.y() - 2);
		}else
		if (plane.x() > x1 - 50 && plane.x() < x1 + vent.width() - 50)
		{
			if(plane.y() > 50)
				plane.nextY(plane.y() - 2);
		}else
		{
			plane.nextY(plane.y() + 2);
		}
        plane.stopIfCollidesWith(TOPEDGE, LEFTEDGE);
        plane.checkIfCollidesWith(BOTTOMEDGE, shelf, desk, bBall, rBall, gBall);
        if (plane.collided())
        {
			level = 2;
		}
		plane.checkIfCollidesWith(RIGHTEDGE);
		if (plane.collided())
		{
			level = 3;
		}
		floor.draw();
		vent.position(x1, canvas.height()-50);
		vent.draw();
		vent.position(x, canvas.height()-50);
		vent.draw();
		bBall.draw();
		rBall.draw();
		gBall.draw();
		desk.draw();
		shelf.draw();
        plane.draw();
		}

		if(level == 2)
		{
			plane.position(x, y);
			bBall.position(canvas.width()/2, canvas.height()/2);
			rBall.position(canvas.width() - 50, canvas.height() - 50);
			gBall.position(canvas.width()/2, canvas.height() - 50);
			button2.draw();
		}

		if(level == 3)
		{
			plane.position(x, y);
			bBall.position(canvas.width()/2 - 100, canvas.height()/2);
			rBall.position(canvas.width() - 250, canvas.height() - 50);
			gBall.position(canvas.width()/2 - 100, canvas.height() - 50);
			button3.draw();
		}
    }

    public void onClickPlayAgain()
    {
		level = 1;
	}

    public void onClickPlay()
    {
		level = 1;
	}

	public void onClickNextLevel()
	{
		level = 1;
	}
}